@@ -52,8 +52,11 @@ class ConfigLoader:
         self.password_cfg = str(data["PasswordCfg"]) if "PasswordCfg" in data else ""
         self.electron_binary_path = (str(data["BinPath"]) if "BinPath" in data else "")
         self.csv_path = (str(data["CSVPath"]) if "CSVPath" in data else "")
-        self.driver_database = str(data["DriverDB"]) if "DriverDB" in data else ""
-        self.server_database = str(data["ServerDB"]) if "ServerDB" in data else ""
-        self.name_database = str(data["NameDB"]) if "NameDB" in data else ""
-        self.user_database = str(data["UserDB"]) if "UserDB" in data else ""
-        self.password_database = str(data["PasswordDB"]) if "PasswordDB" in data else ""
+        self.database_driver = str(data["DBDriver"]) if "DBDriver" in data else ""
+        self.database_server = str(data["DBServer"]) if "DBServer" in data else ""
+        self.database_port = str(data["DBPort"]) if "DBPort" in data else ""
+        self.database_name = str(data["DBName"]) if "DBName" in data else ""
+        self.database_user = str(data["DBUser"]) if "DBUser" in data else ""
+        self.database_password = str(data["DBPassword"]) if "DBPassword" in data else ""
+        self.dbq_oracle_server = str(data["DBQOracleServer"]) if "DBQOracleServer" in data else ""
+
